==> dokuwiki_0.0.20110525a.orig.tar.gz: dokuwiki-2011-05-25a/lib/plugins/plugin/lang/cs/lang.php <==
<?php
/**
 * Czech language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Tomas Valenta <t.valenta@sh.cvut.cz>
 * @author Zbynek Krivka <zbynek.krivka@seznam.cz>
 * @author Bohumir Zamecnik <bohumir@zamecnik.org>
 * @author tomas@valenta.cz
 * @author Marek Sacha <sachamar@fel.cvut.cz>
 * @author Lefty <lefty@multihost.cz>
 * @author Vojta Beran <xmamut@email.cz>
 */
$lang['menu']                  = 'Správa pluginů';
$lang['download']              = 'Stáhnout a instalovat plugin';
$lang['manage']                = 'Seznam instalovaných pluginů';
$lang['btn_info']              = 'info';
$lang['btn_update']            = 'aktualizovat';
$lang['btn_delete']            = 'smazat';
$lang['btn_settings']          = 'nastavení';
$lang['btn_download']          = 'Stáhnout';
$lang['btn_enable']            = 'Uložit';
$lang['url']                   = 'URL';
$lang['installed']             = 'Instalován:';
$lang['lastupdate']            = 'Poslední aktualizace:';
$lang['source']                = 'Zdroj:';
$lang['unknown']               = 'neznámý';
$lang['updating']              = 'Aktualizuji ...';
$lang['updated']               = 'Modul %s úspěšně aktualizován';
$lang['updates']               = 'Následující pluginy byly úspěšně aktualizovány';
$lang['update_none']           = 'Žádné aktualizace nenalezeny.';
$lang['deleting']              = 'Probíhá mazání ...';
$lang['deleted']               = 'Plugin %s smazán.';
$lang['downloading']           = 'Stahuji ...';
$lang['downloaded']            = 'Plugin %s nainstalován';
$lang['downloads']             = 'Následující pluginy byly úspěšně instalovány:';
$lang['download_none']         = 'Žádné pluginy nebyly nenalezeny, nebo se vyskytla nějaká chyba při
stahování a instalaci.';
$lang['plugin']                = 'Plugin:';
$lang['components']            = 'Součásti';
$lang['noinfo']                = 'Plugin nevrátil žádné informace. Může být poškozen nebo špatný.';
$lang['name']                  = 'Jméno:';
$lang['date']                  = 'Datum:';
$lang['type']                  = 'Typ:';
$lang['desc']                  = 'Popis:';
$lang['author']                = 'Autor:';
$lang['www']                   = 'Web:';
$lang['error']                 = 'Nastala neznámá chyba.';
$lang['error_download']        = 'Nelze stáhnout soubor s pluginem: %s';
$lang['error_badurl']          = 'URL je zřejmě chybná - nelze z ní určit název souboru';
$lang['error_dircreate']       = 'Nelze vytvořit dočasný adresář ke stažení dat';
$lang['error_decompress']      = 'Správce pluginů nemůže rozbalit stažený soubor. Toto může být způsobeno chybou při stahování. Můžete se pokusit stahování opakovat. Chyba může být také v kompresním formátu souboru. V tom případě bude nutné stáhnout a nainstalovat plugin ručně.';
$lang['error_copy']            = 'Došlo k chybě při instalaci pluginu <em>%s</em>. Je možné, že na disku není volné místo, nebo mohou být špatně nastavena přístupová práva. Pozor, mohlo dojít k částečné a tudíž chybné instalaci pluginu a tím může být ohrožena stabilita wiki.';
$lang['error_delete']          = 'Došlo k chybě při pokusu o smazání pluginu <em>%s</em>. Nejspíše je chyba v nastavení přístupových práv k některým souborům či adresářům.';
$lang['enabled']               = 'Plugin %s aktivován.';
$lang['notenabled']            = 'Plugin %s nelze aktivovat, zkontrolujte práva k souborům.';
$lang['disabled']              = 'Plugin %s deaktivován.';
$lang['notdisabled']           = 'Plugin %s nelze deaktivovat, zkontrolujte práva k souborům.';
$lang['packageinstalled']      = 'Plugin package (%d plugin%s: %s) úspěšně nainstalován.';

==> dokuwiki_0.0.20131208.orig.tar.gz: dokuwiki-2013-12-08/lib/plugins/plugin/lang/cs/lang.php <==
<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * 
 * @author Tomas Valenta <t.valenta@sh.cvut.cz>
 * @author Zbynek Krivka <zbynek.krivka@seznam.cz>
 * @author Bohumir Zamecnik <bohumir@zamecnik.org>
 * @author tomas@valenta.cz
 * @author Marek Sacha <sachamar@fel.cvut.cz>
 * @author Lefty <lefty@multihost.cz>
 * @author Vojta Beran <xmamut@email.cz>
 * @author zbynek.krivka@seznam.cz
 * @author Bohumir Zamecnik <bohumir.zamecnik@gmail.com>
 * @author Jakub A. Těšínský (j@kub.cz)
 * @author mkucera66@seznam.cz
 * @author Zbyněk Křivka <krivka@fit.vutbr.cz>
 * @author Gerrit Uitslag <klapinklapin@gmail.com>
 */
$lang['menu']                  = 'Správa pluginů';
$lang['download']              = 'Stáhnout a instalovat plugin';
$lang['manage']                = 'Seznam instalovaných pluginů';
$lang['btn_info']              = 'info';
$lang['btn_update']            = 'aktualizovat';
$lang['btn_delete']            = 'smazat';
$lang['btn_settings']          = 'nastavení';
$lang['btn_download']          = 'Stáhnout';
$lang['btn_enable']            = 'Uložit';
$lang['url']                   = 'URL';
$lang['installed']             = 'Instalován:';
$lang['lastupdate']            = 'Poslední aktualizace:';
$lang['source']                = 'Zdroj:';
$lang['unknown']               = 'neznámý';
$lang['updating']              = 'Aktualizuji ...';
$lang['updated']               = 'Modul %s úspěšně aktualizován';
$lang['updates']               = 'Následující pluginy byly úspěšně aktualizovány';
$lang['update_none']           = 'Žádné aktualizace nenalezeny.';
$lang['deleting']              = 'Probíhá mazání ...';
$lang['deleted']               = 'Plugin %s smazán.';
$lang['downloading']           = 'Stahuji ...';
$lang['downloaded']            = 'Plugin %s nainstalován';
$lang['downloads']             = 'Následující pluginy byly úspěšně instalovány:';
$lang['download_none']         = 'Žádné pluginy nebyly nenalezeny, nebo se vyskytla nějaká chyba při
stahování a instalaci.';
$lang['plugin']                = 'Plugin:';
$lang['components']            = 'Součásti';
$lang['noinfo']                = 'Plugin nevrátil žádné informace. Může být poškozen nebo špatný.';
$lang['name']                  = 'Jméno:';
$lang['date']                  = 'Datum:';
$lang['type']                  = 'Typ:';
$lang['desc']                  = 'Popis:';
$lang['author']                = 'Autor:';
$lang['www']                   = 'Web:';
$lang['error']                 = 'Nastala neznámá chyba.';
$lang['error_download']        = 'Nelze stáhnout soubor s pluginem: %s';
$lang['error_badurl']          = 'URL je zřejmě chybná - nelze z ní určit název souboru';
$lang['error_dircreate']       = 'Nelze vytvořit dočasný adresář ke stažení dat';
$lang['error_decompress']      = 'Správce pluginů nemůže rozbalit stažený soubor. Toto může být způsobeno chybou při stahování. Můžete se pokusit stahování opakovat. Chyba může být také v kompresním formátu souboru. V tom případě bude nutné stáhnout a nainstalovat plugin ručně.';
$lang['error_copy']            = 'Došlo k chybě při instalaci pluginu <em>%s</em>. Je možné, že na disku není volné místo, nebo mohou být špatně nastavena přístupová práva. Pozor, mohlo dojít k částečné a tudíž chybné instalaci pluginu a tím může být ohrožena stabilita wiki.';
$lang['error_delete']          = 'Došlo k chybě při pokusu o smazání pluginu <em>%s</em>. Nejspíše je chyba v nastavení přístupových práv k některým souborům či adresářům.';
$lang['enabled']               = 'Plugin %s aktivován.';
$lang['notenabled']            = 'Plugin %s nelze aktivovat, zkontrolujte práva k souborům.';
$lang['disabled']              = 'Plugin %s deaktivován.';
$lang['notdisabled']           = 'Plugin %s nelze deaktivovat, zkontrolujte práva k souborům.';
$lang['packageinstalled']      = 'Balíček pluginů (%d plugin(ů): %s) úspěšně nainstalován.';
